var os = require('os');
var path = require('path');
var multiparty = require('multiparty');
var util = require('util');
var baseDir = path.join(os.homedir(), 'enhancer/data');

var moment = require('moment');
var mkdirp = require('mkdirp');
var serveStatic = require('serve-static');
var serve = serveStatic(baseDir, {'index': ['index.html', 'index.htm']});
var finalhandler = require('finalhandler');

var fileBaseUrl = require('../config').fileBaseUrl;

var MAX_FILE_SIZE = 1024 * 512;

module.exports = {
  upload(req, res, next) {
    var uploadDir = path.join(baseDir, moment().format('YYYYMMDD'));
    res.setHeader('Access-Control-Allow-Origin', '*');
    mkdirp.sync(uploadDir);
    var form = new multiparty.Form({
      uploadDir: uploadDir,
      maxFilesSize: MAX_FILE_SIZE
    });

    var fileBase = req.query.private === 'true' 
      ? req.protocol + '://' + req.headers.host + '/file/'
      : fileBaseUrl;

    form.parse(req, function(err, fields, files) {
      if (err) {
        return res.send({
          success: false,
          message: err.message + '. Notes: The max file size is 512KB in development environment.'
        });
      }
      var ret = [];
      for (var f in files) {
        files[f].forEach(function(file) {
          ret.push({
            filedName: file.filedName,
            originalFilename: file.originalFilename,
            size: file.size,
            url: fileBase + path.relative(baseDir, file.path)
          });
        });
      }
      res.send({
        success: true,
        data: {fields: fields, files: ret}
      });
    });

  },

  download(req, res, next) {
    req.originalUrl = req.originalUrl.replace('/file', '');
    req.url = req.url.replace('/file', '');
    serve(req, res, finalhandler(req, res));
  }
}